Radars
======

.. automodule:: stonesoup.sensor.radar
    :no-members:

.. automodule:: stonesoup.sensor.radar.radar
    :show-inheritance:

Beam Patterns
-------------
.. automodule:: stonesoup.sensor.radar.beam_pattern
    :show-inheritance:

Beam Shapes
-----------
.. automodule:: stonesoup.sensor.radar.beam_shape
    :show-inheritance:
